@@ -14,14 +14,18 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 # flake8: noqa
 # pylint: disable:undefined-variable
+from __future__ import annotations
 
 from pathlib import Path
+
 from pkg_resources import get_distribution
 
 
 __version__ = get_distribution("matrixctl").version
 
 HOME: str = str(Path.home())
+
+
+# vim: set ft=python :
