@@ -52,12 +52,33 @@ def subparser_deploy(subparsers: SubParsersAction) -> None:
 
 
 def deploy(arg: Namespace) -> int:
+    """Deploy the ansible playbook.
+
+    **Contol logic**
+
+    a = ta  (TOML Ansible)
+    b = ts  (TOML SYNAPSE)
+    A = arg.ansible
+    B = arg.synapse
+
+    Empirical:
+    Ansible = a/A/B + aA
+    Synapse = b/A/B + bB
+    Error = /a/b + /aA + /bB
+
+    Optimized (factored SOP):
+
+    Ansible = a(/A/B + A)
+    Synapse = b(/A/B + B)
+    Error = /b(B + /a) + /aA
+    """
     debug("deploy")
     with TOML() as toml:
-        if (
-            toml.get(("ANSIBLE", "Path"), True) is None
-            and toml.get(("SYNAPSE", "Path"), True) is None
-        ):
+        # make them shorter
+        ta: bool = toml.get(("ANSIBLE", "Path"), True) is not None
+        ts: bool = toml.get(("SYNAPSE", "Path"), True) is not None
+
+        if not ts and (arg.synapse or not ta) or not ta and arg.ansible:
             error(
                 "To be able to use the deploy feature, you need to have "
                 "At least your own Ansible playbook configuration in the "
@@ -67,13 +88,13 @@ def deploy(arg: Namespace) -> int:
             )
             sys.exit(1)
 
-        if (toml.get(("ANSIBLE", "Path"), True) is not None) and arg.ansible:
+        if ta and (not arg.ansible and not arg.synape or arg.ansible):
             with Ansible(toml.get(("ANSIBLE", "Path"))) as ansible:
                 ansible.tags = toml.get(("ANSIBLE", "DeployTags"))
                 ansible.ansible_cfg_path = toml.get(("ANSIBLE", "Cfg"))
                 ansible.run_playbook()
 
-        if (toml.get(("SYNAPSE", "Path"), True) is not None) and arg.synapse:
+        if ts and (not arg.ansible and not arg.synapse or arg.synapse):
             with Ansible(toml.get(("SYNAPSE", "Path"))) as ansible:
                 ansible.tags = ("setup-all",)
                 ansible.run_playbook()
